<?php
/**
 * @category    Pinpoint
 * @package     Pinpoint_Faq
 * @copyright   Copyright (c) 2019 Pinpoint Designs. (http://www.Pinpoint.co.uk)
 * @author      Ahmed Goda <hello@Pinpoint.co.uk>
 */

namespace Pinpoint\Faq\Block\Product;

use Magento\Catalog\Api\ProductRepositoryInterface;
use Magento\Framework\Exception\NoSuchEntityException;
use Magento\Framework\View\Element\Template\Context;
use Magento\Framework\View\Element\Template;
use Pinpoint\Faq\Api\Data\FaqInterface;
use Pinpoint\Faq\Api\FaqRepositoryInterface;

/** class Faqs */
class Faqs extends Template
{
    /**
     * Catalog product model
     *
     * @var \Magento\Catalog\Api\ProductRepositoryInterface
     */
    protected $productRepository;

    /**
     * @var FaqRepositoryInterface
     */
    protected $faqRepository;

    /**
     * Form constructor.
     *
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param \Magento\Framework\Url\EncoderInterface $urlEncoder
     * @param \Magento\Catalog\Api\ProductRepositoryInterface $productRepository
     * @param FaqRepositoryInterface $faqRepository
     * @param array $data
     * @throws \RuntimeException
     * @SuppressWarnings(PHPMD.ExcessiveParameterList)
     */
    public function __construct(
        Context $context,
        ProductRepositoryInterface $productRepository,
        FaqRepositoryInterface $faqRepository,
        array $data = []
    ) {
        $this->productRepository = $productRepository;
        $this->faqRepository = $faqRepository;
        parent::__construct($context, $data);
    }

    /**
     * Initialize faq form
     *
     * @return void
     */
    protected function _construct()
    {
        parent::_construct();
        $this->setTemplate('Pinpoint_Faq::product/view/faqs.phtml');
    }

    /**
     * Retrieve current product model
     *
     * @return \Magento\Catalog\Model\Product
     * @throws NoSuchEntityException
     */
    public function getProduct()
    {
        return \Magento\Framework\App\ObjectManager::getInstance()->get('\Magento\Framework\Registry')->registry('current_product');
    }

    /**
     * Get faq product post action
     *
     * @return string
     */
    public function getAction()
    {
        return $this->getUrl(
            'faq/product/post',
            [
                '_secure' => $this->getRequest()->isSecure()
            ]
        );
    }

    /**
     * Get faq product id
     *
     * @return int|null
     * @throws NoSuchEntityException
     */
    protected function getProductId()
    {
        return $this->getProduct()->getId();
    }

    /**
     * @return FaqInterface[]|void|null
     * @throws NoSuchEntityException
     */
    public function getFaqs()
    {
        return $this->faqRepository->getItemsByProductId($this->getProductId());
    }
}
